using System;
using System.Collections.Generic;
using RimWorld;
using RimWorld.Planet;
using UnityEngine;
using Verse;
using Verse.AI;

namespace ReinforcementCall
{
	public class CompMissionBoardRC : ThingComp
	{
		public int tickAtLastMission = -1;

		public CompProperties_MissionBoardRC Props => (CompProperties_MissionBoardRC)props;

		public override IEnumerable<FloatMenuOption> CompFloatMenuOptions(Pawn myPawn)
		{
			FloatMenuOption failureReason = GetFailureReason(myPawn);
			if (failureReason != null)
			{
				yield return failureReason;
				yield break;
			}
			FloatMenuOption option = IncidentFloatMenuOption(myPawn);
			if (option != null)
			{
				yield return option;
			}
		}

		public FloatMenuOption IncidentFloatMenuOption(Pawn negotiator)
		{
			string text = "SelectMissionBoardRC".Translate();
			return FloatMenuUtility.DecoratePrioritizedTask(new FloatMenuOption(text, (Action)delegate
			{
				GiveUseMissionBoardJob(negotiator);
			}, MenuOptionPriority.Default), negotiator, parent);
		}

		public void GiveUseMissionBoardJob(Pawn negotiator)
		{
			Job job = new Job(MBDefsOf.UseMissionBoardRC, parent);
			negotiator.jobs.TryTakeOrderedJob(job, JobTag.Misc);
		}

		private FloatMenuOption GetFailureReason(Pawn myPawn)
		{
			if (!ReachabilityUtility.CanReach(myPawn, (LocalTargetInfo)parent, PathEndMode.InteractionCell, Danger.Some, false))
			{
				return new FloatMenuOption((string)"CannotUseNoPath".Translate(), (Action)null, MenuOptionPriority.Default);
			}
			return null;
		}
	}
}
