using System.Collections.Generic;
using RimWorld;
using Verse;
using Verse.AI;
using Verse.Sound;

namespace ReinforcementCall
{
	public class JobDriver_UseRedPhoneRC : JobDriver
	{
		public override bool TryMakePreToilReservations(bool errorOnFailed)
		{
			Pawn p = pawn;
			LocalTargetInfo targetA = base.job.targetA;
			Job job = base.job;
			return p.Reserve(targetA, job, 1, -1, null, errorOnFailed);
		}

		protected override IEnumerable<Toil> MakeNewToils()
		{
			this.FailOnDespawnedOrNull(TargetIndex.A);
			yield return Toils_Goto.GotoCell(TargetIndex.A, PathEndMode.InteractionCell).FailOn(delegate(Toil to)
			{
				Building_RedPhoneRC building_RedPhoneRC2 = (Building_RedPhoneRC)to.actor.jobs.curJob.GetTarget(TargetIndex.A).Thing;
				return !building_RedPhoneRC2.CanUseCommsNow;
			});
			Toil openComms = new Toil();
			openComms.initAction = delegate
			{
				Pawn actor = openComms.actor;
				Building_RedPhoneRC building_RedPhoneRC = (Building_RedPhoneRC)actor.jobs.curJob.GetTarget(TargetIndex.A).Thing;
				if (building_RedPhoneRC.CanUseCommsNow)
				{
					OpenCommsWith(actor, actor.jobs.curJob.commTarget as Faction);
				}
			};
			yield return openComms;
		}

		public void OpenCommsWith(Pawn negotiator, Faction faction)
		{
			Dialog_Negotiation dialog_Negotiation = new Dialog_Negotiation(negotiator, faction, ReinforcementDialogMakerRC.FactionDialogFor(negotiator, faction), radioMode: true);
			dialog_Negotiation.soundAmbient = RCDefsOf.AmbientRedPhoneRC;
			RCDefsOf.PickUpRedPhoneRC.PlayOneShot(SoundInfo.OnCamera());
			Find.WindowStack.Add(dialog_Negotiation);
		}
	}
}
