using System.Collections.Generic;
using System.Linq;
using RimWorld;
using Verse;
using Verse.Sound;

namespace ReinforcementCall
{
	public static class MissionBoardDialogMakerRC
	{
		public static DiaNode MissionSelectWindow(Building missionBoard, Map map)
		{
			DiaNode diaNode = new DiaNode("SelectMissionRC".Translate());
			if (map != null && map.IsPlayerHome && missionBoard.GetComp<CompMissionBoardRC>() != null)
			{
				List<LabeledIncident> doableMissions = missionBoard.GetComp<CompMissionBoardRC>().Props.doableMissions;
				List<LabeledQuestScript> doableQuests = missionBoard.GetComp<CompMissionBoardRC>().Props.doableQuests;
				if (doableMissions != null)
				{
					foreach (LabeledIncident item in doableMissions)
					{
						diaNode.options.Add(StartMissionOption(map, item, missionBoard));
					}
				}
				if (doableQuests != null)
				{
					foreach (LabeledQuestScript item2 in doableQuests)
					{
						diaNode.options.Add(StartQuestOption(map, item2, missionBoard));
					}
				}
			}
			DiaOption diaOption = new DiaOption("(" + "Close".Translate() + ")");
			diaOption.resolveTree = true;
			diaNode.options.Add(diaOption);
			return diaNode;
		}

		private static void StartMission(Map map, IncidentDef incident)
		{
			IncidentParms incidentParms = new IncidentParms();
			incidentParms.target = map;
			incidentParms.points = StorytellerUtility.DefaultThreatPointsNow(map);
			incident.Worker.TryExecute(incidentParms);
			MBDefsOf.OneShotMissionSelectedRC.PlayOneShotOnCamera();
		}

		private static void StartQuest(Map map, QuestScriptDef quest)
		{
			IncidentParms incidentParms = new IncidentParms();
			incidentParms.target = map;
			incidentParms.points = StorytellerUtility.DefaultThreatPointsNow(map);
			QuestUtility.SendLetterQuestAvailable(QuestUtility.GenerateQuestAndMakeAvailable(quest, incidentParms.points));
			MBDefsOf.OneShotMissionSelectedRC.PlayOneShotOnCamera();
		}

		public static DiaOption StartMissionOption(Map map, LabeledIncident labeledIncident, Building missionBoard)
		{
			int silverToPay = 500;
			string customLabel = labeledIncident.customLabel;
			DiaOption diaOption = new DiaOption(customLabel);
			int num = missionBoard.GetComp<CompMissionBoardRC>().tickAtLastMission + 60000 - Find.TickManager.TicksGame;
			if (num > 0)
			{
				DiaOption diaOption2 = new DiaOption(customLabel);
				diaOption2.Disable("WaitTime".Translate(num.ToStringTicksToPeriod()));
				return diaOption2;
			}
			if (AmountSendableSilver(map) < silverToPay)
			{
				DiaOption diaOption3 = new DiaOption(customLabel);
				diaOption3.Disable("NeedSilverLaunchable".Translate(silverToPay.ToString()));
				return diaOption3;
			}
			diaOption.action = delegate
			{
				StartMission(map, labeledIncident.incidentDef);
				TradeUtility.LaunchThingsOfType(ThingDefOf.Silver, silverToPay, map, null);
				missionBoard.GetComp<CompMissionBoardRC>().tickAtLastMission = Find.TickManager.TicksGame;
			};
			diaOption.resolveTree = true;
			return diaOption;
		}

		public static DiaOption StartQuestOption(Map map, LabeledQuestScript labeledQuestScript, Building missionBoard)
		{
			int silverToPay = 500;
			string customLabel = labeledQuestScript.customLabel;
			DiaOption diaOption = new DiaOption(customLabel);
			int num = missionBoard.GetComp<CompMissionBoardRC>().tickAtLastMission + 60000 - Find.TickManager.TicksGame;
			if (num > 0)
			{
				DiaOption diaOption2 = new DiaOption(customLabel);
				diaOption2.Disable("WaitTime".Translate(num.ToStringTicksToPeriod()));
				return diaOption2;
			}
			if (AmountSendableSilver(map) < silverToPay)
			{
				DiaOption diaOption3 = new DiaOption(customLabel);
				diaOption3.Disable("NeedSilverLaunchable".Translate(silverToPay.ToString()));
				return diaOption3;
			}
			diaOption.action = delegate
			{
				StartQuest(map, labeledQuestScript.incidentDef);
				TradeUtility.LaunchThingsOfType(ThingDefOf.Silver, silverToPay, map, null);
				missionBoard.GetComp<CompMissionBoardRC>().tickAtLastMission = Find.TickManager.TicksGame;
			};
			diaOption.resolveTree = true;
			return diaOption;
		}

		private static int AmountSendableSilver(Map map)
		{
			return (from t in TradeUtility.AllLaunchableThingsForTrade(map)
				where t.def == ThingDefOf.Silver
				select t).Sum((Thing t) => t.stackCount);
		}
	}
}
